@@ -4,12 +4,14 @@ from __future__ import annotations
 import copy
 import uuid
 from dataclasses import asdict, make_dataclass
-from typing import TYPE_CHECKING, Any, Literal, TypeGuard, TypeVar, cast
+from typing import TYPE_CHECKING, Any, TypeGuard, TypeVar, cast
 
 from .basic_types import (
     Action,
     BaseAction,
+    BaseEvent,
     CompleteReducerResult,
+    Event,
     Immutable,
     InitAction,
     is_reducer_result,
@@ -27,23 +29,13 @@ class BaseCombineReducerAction(BaseAction):
     _id: str
 
 
-class CombineReducerRegisterActionPayload(Immutable):
+class CombineReducerRegisterAction(BaseCombineReducerAction):
     key: str
     reducer: ReducerType
 
 
-class CombineReducerRegisterAction(BaseCombineReducerAction):
-    payload: CombineReducerRegisterActionPayload
-    type: Literal['REGISTER'] = 'REGISTER'
-
-
-class CombineReducerUnregisterActionPayload(Immutable):
-    key: str
-
-
 class CombineReducerUnregisterAction(BaseCombineReducerAction):
-    payload: CombineReducerUnregisterActionPayload
-    type: Literal['UNREGISTER'] = 'UNREGISTER'
+    key: str
 
 
 CombineReducerAction = CombineReducerRegisterAction | CombineReducerUnregisterAction
@@ -59,10 +51,11 @@ def is_combine_reducer_action(action: BaseAction) -> TypeGuard[CombineReducerAct
 
 
 def combine_reducers(
-    action_type: type[Action],  # noqa: ARG001
     state_type: type[CombineReducerState],
+    action_type: type[Action] = BaseAction,  # noqa: ARG001
+    event_type: type[Event] = BaseEvent,  # noqa: ARG001
     **reducers: ReducerType,
-) -> tuple[ReducerType[CombineReducerState, Action], str]:
+) -> tuple[ReducerType[CombineReducerState, Action, Event], str]:
     _id = uuid.uuid4().hex
 
     state_class = cast(
@@ -78,12 +71,12 @@ def combine_reducers(
     def combined_reducer(
         state: CombineReducerState | None,
         action: Action,
-    ) -> CompleteReducerResult[CombineReducerState, Action]:
+    ) -> CompleteReducerResult[CombineReducerState, Action, Event]:
         nonlocal state_class
         if state is not None and is_combine_reducer_action(action):
-            if action.type == 'REGISTER' and action._id == _id:  # noqa: SLF001
-                key = action.payload.key
-                reducer = action.payload.reducer
+            if isinstance(action, CombineReducerRegisterAction) and action._id == _id:  # noqa: SLF001
+                key = action.key
+                reducer = action.reducer
                 reducers[key] = reducer
                 state_class = make_dataclass(
                     'combined_reducer',
@@ -94,18 +87,17 @@ def combine_reducers(
                     _id=state._id,  # noqa: SLF001
                     **(
                         {
-                            key_: reducer(
-                                None,
-                                InitAction(type='INIT'),
-                            )
+                            key_: reducer(None, InitAction())
                             if key == key_
                             else getattr(state, key_)
                             for key_ in reducers
                         }
                     ),
                 )
-            elif action.type == 'UNREGISTER' and action._id == _id:  # noqa: SLF001
-                key = action.payload.key
+            elif (
+                isinstance(action, CombineReducerUnregisterAction) and action._id == _id  # noqa: SLF001
+            ):
+                key = action.key
 
                 del reducers[key]
                 fields_copy = copy.copy(cast(Any, state_class).__dataclass_fields__)
